==> dif-database-repository-2.3.11-2-sources.jar: pt/digitalis/dif/dem/managers/impl/model/impl/UserPreferencesServiceImpl.java <==
package pt.digitalis.dif.dem.managers.impl.model.impl;

import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.utils.common.IBeanAttributes;

import pt.digitalis.dif.dem.managers.impl.model.IUserPreferencesService;
import pt.digitalis.dif.dem.managers.impl.model.dao.IUserPreferencesDAO;
import pt.digitalis.dif.dem.managers.impl.model.dao.impl.UserPreferencesDAOImpl;
import pt.digitalis.dif.dem.managers.impl.model.data.UserPreferences;

/**
 * NOTE: This file is auto generated and will be overwrite in a future file generation.
 */
public class UserPreferencesServiceImpl implements IUserPreferencesService {

	/**
	 * Obtains a new UserPreferences DAO
	 *
	 * @return A new IUserPreferencesDAO
	 */
    public IUserPreferencesDAO getUserPreferencesDAO() {
    	return new UserPreferencesDAOImpl();
    }

    /**
     * Obtains a new DataSet for the UserPreferences entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<UserPreferences> getUserPreferencesDataSet() {
        return new HibernateDataSet<UserPreferences>(UserPreferences.class, new UserPreferencesDAOImpl(),
                UserPreferences.getPKFieldListAsString());
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz) {

        if (clazz == UserPreferences.class)
            return getUserPreferencesDataSet();

        return null;
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(String entityName) {

        if (entityName.equalsIgnoreCase(UserPreferences.class.getSimpleName()))
            return getUserPreferencesDataSet();

        return null;
    }
}

==> dif-database-repository-2.6.1-8-20200421.173538-1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/impl/UserPreferencesServiceImpl.java <==
package pt.digitalis.dif.dem.managers.impl.model.impl;

import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.utils.common.IBeanAttributes;

import pt.digitalis.dif.dem.managers.impl.model.IUserPreferencesService;
import pt.digitalis.dif.dem.managers.impl.model.dao.auto.IUserPreferencesDAO;
import pt.digitalis.dif.dem.managers.impl.model.dao.auto.impl.UserPreferencesDAOImpl;
import pt.digitalis.dif.dem.managers.impl.model.data.UserPreferences;

/**
 * NOTE: This file is auto generated and will be overwrite in a future file generation.
 */
public class UserPreferencesServiceImpl implements IUserPreferencesService {

	/**
	 * Obtains a new UserPreferences DAO
	 *
	 * @return A new IUserPreferencesDAO
	 */
    public IUserPreferencesDAO getUserPreferencesDAO() {
    	return new UserPreferencesDAOImpl();
    }

    /**
     * Obtains a new DataSet for the UserPreferences entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<UserPreferences> getUserPreferencesDataSet() {
        return new HibernateDataSet<UserPreferences>(UserPreferences.class, new UserPreferencesDAOImpl(),
                UserPreferences.getPKFieldListAsString());
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz) {

        if (clazz == UserPreferences.class)
            return getUserPreferencesDataSet();

        return null;
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(String entityName) {

        if (entityName.equalsIgnoreCase(UserPreferences.class.getSimpleName()))
            return getUserPreferencesDataSet();

        return null;
    }
}
